# *******************************************************************************
# *
# * SmartObjects is developed by iuveno AG and the SmartObjects community. It can
# * be used under the same terms as Python or Zope. A specific license will be
# * announced after the first release.
# *
# * Note: Please comment all the code you have written or change comments when
# * the functionality changes. Make notes of the new features and posty them to
# * the list or put them on the official SmartObjects Web site. Furthermore,
# * at the end of the day, always make a change log entry in this file, in
# * addition to the CVS comments.
# *
# * File:       HTMLForm.py - This class implements a SmartForm for HTML 
# * Maintainer: Stephan Richter (srichter@iuveno-net.de)
# * Changed on: May 29, 2001
# *
# *******************************************************************************

# Change Log:
# (Format: * DD/MM/YYYY (<initals>) - <short description of changes>)
#
# * 29/05/2001 (SR) - Initial creation of the file and the HTMLForm class

from Products.Formulator.Form import ZMIForm
from Globals                  import DTMLFile
from OFS.DTMLMethod           import DTMLMethod 
from OFS.Folder               import Folder
from AccessControl            import ClassSecurityInfo


manage_addHTMLFormForm = DTMLFile('dtml/addHTMLForm', globals())


def manage_addHTMLForm(self, id, title='', REQUEST=None):
    ''' '''
    form = HTMLForm(id, title)
    self._setObject(id, form)

    if REQUEST:
        return self.manage_main(self, REQUEST)


_contents = '''
<dtml-var standard_html_header>

<form action="&dtml-URL1;" method="POST" enctype="&dtml-enctype;">
  <dtml-if "REQUEST.has_key('nextURL')">
    <input type="hidden" name="nextURL" value="&dtml-nextURL;">    
  </dtml-if>
  <dtml-if "REQUEST.has_key('position')">
    <input type="hidden" name="position" value="&dtml-position;">    
  </dtml-if>
  <table cellspacing="0" cellpadding="2" border="0">
    <dtml-in "get_fields()"><dtml-let field=sequence-item>
      <tr>
        <td class="form-label">
          <dtml-var "field.get_value('title')">
        </td>
        <td>
          <dtml-if "_.hasattr(PARENTS[1], field.id)">
            <dtml-var "field.render(_.getattr(PARENTS[1],field.id))">
          <dtml-else>
            <dtml-var "field.render()">
          </dtml-if>
        </td>
      </tr>
    </dtml-let></dtml-in>
    <tr>
      <td colspan="2">
        <dtml-if "REQUEST.has_key('mode') and mode == 'Add'"> 
          <input type="submit" name="&dtml-addAction;:method" value="&dtml-submitAddLabel;">
        <dtml-else>
          <input type="submit" name="&dtml-editAction;:method" value="&dtml-submitEditLabel;">
        </dtml-if>
        <input type="submit" name="&dtml-cancelAction;:method" value="&dtml-submitCancelLabel;">
    </tr>
  </table>
</form>

<dtml-var standard_html_footer>
'''


class HTMLForm(ZMIForm, Folder):
    '''HTMLForm class - Implements a Form for HTML'''

    meta_type = 'HTML Form'

    _properties = ( {'id': 'enctype',           'type': 'string', 'mode': 'w',
                     'default': 'application/x-www-form-urlencoded'}, 
                    {'id': 'submitAddLabel',    'type': 'string', 'mode': 'w', 'default': ' Add '},
                    {'id': 'submitEditLabel',   'type': 'string', 'mode': 'w', 'default': ' Edit '},
                    {'id': 'submitCancelLabel', 'type': 'string', 'mode': 'w', 'default': 'Cancel'},
                    {'id': 'addAction',         'type': 'string', 'mode': 'w', 'default': 'manage_add'},
                    {'id': 'editAction',        'type': 'string', 'mode': 'w', 'default': 'manage_edit'},
                    {'id': 'cancelAction',      'type': 'string', 'mode': 'w', 'default': 'manage_cancel'} )
                    

    manage_options = (
        Folder.manage_options + 
        ( {'label':'Render Method', 'action':'renderMethod/manage_main',
           'help':('Formulator', 'formContents.txt')},
          {'label':'Order', 'action':'formOrder',
           'help':('Formulator', 'formOrder.txt')},
          {'label':'Test', 'action':'formTest',
           'help':('Formulator', 'formTest.txt')}, ) 
        )


    security = ClassSecurityInfo()
    security.declareProtected('View management screens', 'manage_render')


    old__init__ = ZMIForm.__init__
    def __init__(self, id, title=''):
        ''' '''
        self.old__init__(id, title)

        for prop in self._properties:
            self._setPropValue(prop['id'], prop['default'])

        self.renderMethod = DTMLMethod(_contents, __name__ = 'renderMethod')
